@@ -23,7 +23,7 @@
  * @package jk_connect
  * @author      Gal Shachor <shachor@il.ibm.com>
  * @author      Mladen Turk <mturk@apache.org>
- * @version     $Revision: 1658173 $
+ * @version     $Revision: 1841818 $
  */
 
 
@@ -47,7 +47,7 @@ static apr_pool_t *jk_apr_pool = NULL;
 #include <poll.h>
 #endif
 
-#if defined(WIN32) || (defined(NETWARE) && defined(__NOVELL_LIBC__))
+#if defined(WIN32)
 #define JK_IS_SOCKET_ERROR(x) ((x) == SOCKET_ERROR)
 #define JK_GET_SOCKET_ERRNO() errno = WSAGetLastError() - WSABASEERR
 #else
@@ -55,10 +55,6 @@ static apr_pool_t *jk_apr_pool = NULL;
 #define JK_GET_SOCKET_ERRNO() ((void)0)
 #endif /* WIN32 */
 
-#if defined(NETWARE) && defined(__NOVELL_LIBC__)
-#define USE_SOCK_CLOEXEC
-#endif
-
 #ifndef INET6_ADDRSTRLEN
 /* Maximum size of an IPv6 address in ASCII */
 #define INET6_ADDRSTRLEN 46
@@ -82,13 +78,6 @@ static apr_pool_t *jk_apr_pool = NULL;
 #define EAFNOSUPPORT WSAEAFNOSUPPORT
 #endif
 
-/* our compiler cant deal with char* <-> const char* ... */
-#if defined(NETWARE) && !defined(__NOVELL_LIBC__)
-typedef char* SET_TYPE;
-#else
-typedef const char* SET_TYPE;
-#endif
-
 /** Set socket to blocking
  * @param sd  socket to manipulate
  * @return    errno: fcntl returns -1 (!WIN32)
@@ -98,7 +87,7 @@ typedef const char* SET_TYPE;
 static int soblock(jk_sock_t sd)
 {
 /* BeOS uses setsockopt at present for non blocking... */
-#if defined (WIN32) || (defined(NETWARE) && defined(__NOVELL_LIBC__))
+#if defined (WIN32)
     u_long on = 0;
     if (JK_IS_SOCKET_ERROR(ioctlsocket(sd, FIONBIO, &on))) {
         JK_GET_SOCKET_ERRNO();
@@ -120,7 +109,7 @@ static int soblock(jk_sock_t sd)
     if (fcntl(sd, F_SETFL, fd_flags) == -1) {
         return errno;
     }
-#endif /* WIN32 || (NETWARE && __NOVELL_LIBC__) */
+#endif /* WIN32 */
     return 0;
 }
 
@@ -132,7 +121,7 @@ static int soblock(jk_sock_t sd)
  */
 static int sononblock(jk_sock_t sd)
 {
-#if defined (WIN32) || (defined(NETWARE) && defined(__NOVELL_LIBC__))
+#if defined (WIN32)
     u_long on = 1;
     if (JK_IS_SOCKET_ERROR(ioctlsocket(sd, FIONBIO, &on))) {
         JK_GET_SOCKET_ERRNO();
@@ -154,11 +143,11 @@ static int sononblock(jk_sock_t sd)
     if (fcntl(sd, F_SETFL, fd_flags) == -1) {
         return errno;
     }
-#endif /* WIN32 || (NETWARE && __NOVELL_LIBC__) */
+#endif /* WIN32 */
     return 0;
 }
 
-#if defined (WIN32) || (defined(NETWARE) && defined(__NOVELL_LIBC__))
+#if defined (WIN32)
 /* WIN32 implementation */
 /** Non-blocking socket connect
  * @param sd       socket to connect
@@ -242,9 +231,75 @@ static int nb_connect(jk_sock_t sd, jk_sockaddr_t *addr, jk_sockaddr_t *source,
     JK_TRACE_EXIT(l);
     return 0;
 }
+#elif defined(HAVE_POLL_H)
+/* POSIX implementation using poll(2) */
+/** Non-blocking socket connect
+ * @param sd       socket to connect
+ * @param addr     address to connect to
+ * @param source   optional source address
+ * @param timeout  connect timeout in seconds
+ *                 (<=0: no timeout=blocking)
+ * @param l        logger
+ * @return         -1: some kind of error occured
+ *                 0: success
+ */
+static int nb_connect(jk_sock_t sd, jk_sockaddr_t *addr, jk_sockaddr_t *source,
+                      int timeout, jk_logger_t *l) {
+    int rc = 0;
+    char buf[64];
 
-#elif !defined(NETWARE)
-/* POSIX implementation */
+    JK_TRACE_ENTER(l);
+
+    if (source != NULL) {
+        if (bind(sd, (const struct sockaddr *)&source->sa.sin, source->salen)) {
+            JK_GET_SOCKET_ERRNO();
+            jk_log(l, JK_LOG_ERROR,
+                   "error during source bind on socket %d [%s] (errno=%d)", sd,
+                   jk_dump_hinfo(source, buf, sizeof(buf)), errno);
+        }
+    }
+    if (timeout > 0) {
+        if (sononblock(sd)) {
+            JK_TRACE_EXIT(l);
+            return -1;
+        }
+    }
+    do {
+        rc = connect(sd, (const struct sockaddr *)&addr->sa.sin, addr->salen);
+    } while (rc == -1 && errno == EINTR);
+
+    if ((rc == -1) && (errno == EINPROGRESS || errno == EALREADY)
+                   && (timeout > 0)) {
+        struct pollfd pfd;
+        socklen_t rclen = (socklen_t)sizeof(rc);
+        pfd.fd = sd;
+        pfd.events = POLLOUT;
+        rc = poll(&pfd, 1, timeout);
+        if (rc <= 0) {
+            /* Save errno */
+            int err = errno;
+            soblock(sd);
+            errno = err;
+            JK_TRACE_EXIT(l);
+            return -1;
+        }
+        rc = 0;
+#ifdef SO_ERROR
+        if (getsockopt(sd, SOL_SOCKET, SO_ERROR,
+                       (char *)&rc, &rclen) < 0 || rc) {
+            if (rc)
+                errno = rc;
+            rc = -1;
+        }
+#endif
+    }
+    soblock(sd);
+    JK_TRACE_EXIT(l);
+    return rc;
+}
+
+#else
+/* POSIX implementation using select(2) */
 /** Non-blocking socket connect
  * @param sd       socket to connect
  * @param addr     address to connect to
@@ -318,58 +373,6 @@ static int nb_connect(jk_sock_t sd, jk_sockaddr_t *addr, jk_sockaddr_t *source,
     JK_TRACE_EXIT(l);
     return rc;
 }
-#else
-/* NETWARE implementation - blocking for now */
-/** Non-blocking socket connect
- * @param sd       socket to connect
- * @param addr     address to connect to
- * @param source   optional source address
- * @param timeout  connect timeout in seconds (ignored!)
- * @param l        logger
- * @return         -1: some kind of error occured
- *                 0: success
- */
-static int nb_connect(jk_sock_t sd, jk_sockaddr_t *addr, jk_sockaddr_t *source,
-                      int timeout, jk_logger_t *l)
-{
-    int rc;
-    char buf[64];
-
-    JK_TRACE_ENTER(l);
-
-    if (source != NULL) {
-        if (bind(sd, (const struct sockaddr *)&source->sa.sin, source->salen)) {
-            JK_GET_SOCKET_ERRNO();
-            jk_log(l, JK_LOG_ERROR,
-                   "error during source bind on socket %d [%s] (errno=%d)",
-                   sd, jk_dump_hinfo(source, buf, sizeof(buf)), errno);
-        }
-    }
-    rc = connect(sd, (const struct sockaddr *)&addr->sa.sin, addr->salen);
-    JK_TRACE_EXIT(l);
-    return rc;
-}
-#endif
-
-
-#ifdef AS400_UTF8
-
-/*
- *  i5/OS V5R4 need EBCDIC for its runtime calls but APR/APACHE works in UTF
- */
-in_addr_t jk_inet_addr(const char * addrstr)
-{
-    in_addr_t addr;
-    char *ptr;
-
-    ptr = (char *)malloc(strlen(addrstr) + 1);
-    jk_ascii2ebcdic((char *)addrstr, ptr);
-    addr = inet_addr(ptr);
-    free(ptr);
-
-    return(addr);
-}
-
 #endif
 
 /** Clone a jk_sockaddr_t
@@ -490,7 +493,7 @@ int jk_resolve(const char *host, int port, jk_sockaddr_t *saddr,
         
 #if JK_HAVE_IPV6
         if (strchr(host, ':')) {
-            /* If host name contains collon this must be IPV6 address.
+            /* If host name contains colon this must be IPV6 address.
              * Set prefer_ipv6 flag in this case if it wasn't set already
              */
             prefer_ipv6 = 1;            
@@ -564,11 +567,7 @@ int jk_resolve(const char *host, int port, jk_sockaddr_t *saddr,
 
         /* XXX : WARNING : We should really use gethostbyname_r in multi-threaded env */
         /* Fortunatly when APR is available, ie under Apache 2.0, we use it */
-#if defined(NETWARE) && !defined(__NOVELL_LIBC__)
-        hoste = gethostbyname((char*)host);
-#else
         hoste = gethostbyname(host);
-#endif
         if (!hoste) {
             JK_TRACE_EXIT(l);
             return JK_FALSE;
@@ -662,7 +661,7 @@ jk_sock_t jk_open_socket(jk_sockaddr_t *addr, jk_sockaddr_t *source,
 #endif
 
     /* Disable Nagle algorithm */
-    if (setsockopt(sd, IPPROTO_TCP, TCP_NODELAY, (SET_TYPE)&set,
+    if (setsockopt(sd, IPPROTO_TCP, TCP_NODELAY, (const char*)&set,
                    sizeof(set))) {
         JK_GET_SOCKET_ERRNO();
         jk_log(l, JK_LOG_ERROR,
@@ -675,7 +674,7 @@ jk_sock_t jk_open_socket(jk_sockaddr_t *addr, jk_sockaddr_t *source,
         jk_log(l, JK_LOG_DEBUG,
                "socket TCP_NODELAY set to On");
     if (keepalive) {
-#if defined(WIN32) && !defined(NETWARE)
+#if defined(WIN32)
         DWORD dw;
         struct tcp_keepalive ka = { 0 }, ks = { 0 };
         if (timeout)
@@ -699,7 +698,7 @@ jk_sock_t jk_open_socket(jk_sockaddr_t *addr, jk_sockaddr_t *source,
                    ka.keepalivetime / 1000);
 #else
         set = 1;
-        if (setsockopt(sd, SOL_SOCKET, SO_KEEPALIVE, (SET_TYPE)&set,
+        if (setsockopt(sd, SOL_SOCKET, SO_KEEPALIVE, (const char*)&set,
                        sizeof(set))) {
             JK_GET_SOCKET_ERRNO();
             jk_log(l, JK_LOG_ERROR,
@@ -717,7 +716,7 @@ jk_sock_t jk_open_socket(jk_sockaddr_t *addr, jk_sockaddr_t *source,
     if (sock_buf > 0) {
         set = sock_buf;
         /* Set socket send buffer size */
-        if (setsockopt(sd, SOL_SOCKET, SO_SNDBUF, (SET_TYPE)&set,
+        if (setsockopt(sd, SOL_SOCKET, SO_SNDBUF, (const char*)&set,
                         sizeof(set))) {
             JK_GET_SOCKET_ERRNO();
             jk_log(l, JK_LOG_ERROR,
@@ -728,7 +727,7 @@ jk_sock_t jk_open_socket(jk_sockaddr_t *addr, jk_sockaddr_t *source,
         }
         set = sock_buf;
         /* Set socket receive buffer size */
-        if (setsockopt(sd, SOL_SOCKET, SO_RCVBUF, (SET_TYPE)&set,
+        if (setsockopt(sd, SOL_SOCKET, SO_RCVBUF, (const char*)&set,
                                 sizeof(set))) {
             JK_GET_SOCKET_ERRNO();
             jk_log(l, JK_LOG_ERROR,
@@ -744,7 +743,7 @@ jk_sock_t jk_open_socket(jk_sockaddr_t *addr, jk_sockaddr_t *source,
     }
 
     if (timeout > 0) {
-#if defined(WIN32) || (defined(NETWARE) && defined(__NOVELL_LIBC__))
+#if defined(WIN32)
         int tmout = timeout * 1000;
         setsockopt(sd, SOL_SOCKET, SO_RCVTIMEO,
                    (const char *) &tmout, sizeof(int));
@@ -784,7 +783,7 @@ jk_sock_t jk_open_socket(jk_sockaddr_t *addr, jk_sockaddr_t *source,
 #ifdef SO_LINGER
     /* Make hard closesocket by disabling lingering */
     li.l_linger = li.l_onoff = 0;
-    if (setsockopt(sd, SOL_SOCKET, SO_LINGER, (SET_TYPE)&li,
+    if (setsockopt(sd, SOL_SOCKET, SO_LINGER, (const char*)&li,
                    sizeof(li))) {
         JK_GET_SOCKET_ERRNO();
         jk_log(l, JK_LOG_ERROR,
@@ -806,7 +805,7 @@ iSeries when Unix98 is required at compile time */
     ((struct sockaddr *)addr)->sa.sin.sa_len = sizeof(struct sockaddr_in);
 #endif
     ret = nb_connect(sd, addr, source, connect_timeout, l);
-#if defined(WIN32) || (defined(NETWARE) && defined(__NOVELL_LIBC__))
+#if defined(WIN32)
     if (JK_IS_SOCKET_ERROR(ret)) {
         JK_GET_SOCKET_ERRNO();
     }
@@ -850,7 +849,7 @@ int jk_close_socket(jk_sock_t sd, jk_logger_t *l)
     }
 
     save_errno = errno;
-#if defined(WIN32) || (defined(NETWARE) && defined(__NOVELL_LIBC__))
+#if defined(WIN32)
     rc = closesocket(sd) ? -1 : 0;
 #else
     do {
@@ -955,7 +954,7 @@ int jk_shutdown_socket(jk_sock_t sd, jk_logger_t *l)
             int num = 0;
             do {
                 num++;
-#if defined(WIN32) || (defined(NETWARE) && defined(__NOVELL_LIBC__))
+#if defined(WIN32)
                 rc = recv(sd, &dummy[0], sizeof(dummy), 0);
                 if (JK_IS_SOCKET_ERROR(rc))
                     JK_GET_SOCKET_ERRNO();
@@ -1045,7 +1044,7 @@ int jk_tcp_socket_sendfull(jk_sock_t sd, const unsigned char *b, int len, jk_log
     errno = 0;
     while (sent < len) {
         do {
-#if defined(WIN32) || (defined(NETWARE) && defined(__NOVELL_LIBC__))
+#if defined(WIN32)
             wr = send(sd, (const char*)(b + sent),
                       len - sent, 0);
             if (JK_IS_SOCKET_ERROR(wr))
@@ -1096,7 +1095,7 @@ int jk_tcp_socket_recvfull(jk_sock_t sd, unsigned char *b, int len, jk_logger_t
     errno = 0;
     while (rdlen < len) {
         do {
-#if defined(WIN32) || (defined(NETWARE) && defined(__NOVELL_LIBC__))
+#if defined(WIN32)
             rd = recv(sd, (char *)b + rdlen,
                       len - rdlen, 0);
             if (JK_IS_SOCKET_ERROR(rd))
@@ -1285,17 +1284,22 @@ char *jk_dump_hinfo(jk_sockaddr_t *saddr, char *buf, size_t size)
 {
     char pb[8];
 
-    if (saddr->family == JK_INET) {
-        inet_ntop4(saddr->ipaddr_ptr, buf, size);
-    }
+    if (saddr->ipaddr_ptr == NULL) {
+        strcpy(buf, "UnresolvedIP");
+    } else {
+        if (saddr->family == JK_INET) {
+            inet_ntop4(saddr->ipaddr_ptr, buf, size);
+        }
 #if JK_HAVE_IPV6
-    else {
-        inet_ntop6(saddr->ipaddr_ptr, buf, size);
-    }
+        else {
+            inet_ntop6(saddr->ipaddr_ptr, buf, size);
+        }
 #endif
+    }
+ 
     sprintf(pb, ":%d", saddr->port);
-
     strncat(buf, pb, size - strlen(buf) - 1);
+
     return buf;
 }
 
@@ -1443,7 +1447,7 @@ int jk_is_input_event(jk_sock_t sd, int timeout, jk_logger_t *l)
                    sd, jk_dump_sinfo(sd, buf, sizeof(buf)), timeout);
         }
         /* Timeout. Set the errno to timeout */
-#if defined(WIN32) || (defined(NETWARE) && defined(__NOVELL_LIBC__))
+#if defined(WIN32)
         errno = WSAETIMEDOUT - WSABASEERR;
 #else
         errno = ETIMEDOUT;
@@ -1547,7 +1551,7 @@ int jk_is_socket_connected(jk_sock_t sd, jk_logger_t *l)
         return JK_TRUE;
     }
     else if (rc == 1) {
-#if defined(WIN32) || (defined(NETWARE) && defined(__NOVELL_LIBC__))
+#if defined(WIN32)
         u_long nr;
         rc = ioctlsocket(sd, FIONREAD, &nr);
         if (rc == 0) {
