@@ -18,7 +18,7 @@
 /***************************************************************************
  * Description: Socket connections header file                             *
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
- * Version:     $Revision: 995751 $                                               *
+ * Version:     $Revision: 1837376 $                                               *
  ***************************************************************************/
 
 #ifndef JK_CONNECT_H
@@ -27,7 +27,7 @@
 #include "jk_logger.h"
 #include "jk_global.h"
 
-#if !defined(WIN32) && !(defined(NETWARE) && defined(__NOVELL_LIBC__))
+#if !defined(WIN32)
 #define closesocket         close
 #endif
 
@@ -38,9 +38,13 @@ extern "C"
 
 #define JK_SOCKET_EOF      (-2)
 
-int jk_resolve(const char *host, int port, struct sockaddr_in *rc, void *pool, jk_logger_t *l);
+void jk_clone_sockaddr(jk_sockaddr_t *out, jk_sockaddr_t *in);
 
-jk_sock_t jk_open_socket(struct sockaddr_in *addr, int keepalive,
+int jk_resolve(const char *host, int port, jk_sockaddr_t *rc, void *pool,
+               int prefer_ipv6, jk_logger_t *l);
+
+jk_sock_t jk_open_socket(jk_sockaddr_t *addr, jk_sockaddr_t *source,
+                         int keepalive,
                          int timeout, int connect_timeout,
                          int sock_buf, jk_logger_t *l);
 
@@ -52,9 +56,9 @@ int jk_tcp_socket_sendfull(jk_sock_t sd, const unsigned char *b, int len, jk_log
 
 int jk_tcp_socket_recvfull(jk_sock_t sd, unsigned char *b, int len, jk_logger_t *l);
 
-char *jk_dump_hinfo(struct sockaddr_in *saddr, char *buf);
+char *jk_dump_hinfo(jk_sockaddr_t *saddr, char *buf, size_t size);
 
-char *jk_dump_sinfo(jk_sock_t sd, char *buf);
+char *jk_dump_sinfo(jk_sock_t sd, char *buf, size_t size);
 
 int jk_is_input_event(jk_sock_t sd, int timeout, jk_logger_t *l);
 
