@@ -22,7 +22,7 @@
  * Author:      Mladen Turk <mturk@apache.org>                             *
  * Author:      Rainer Jung <rjung@apache.org>                             *
  * Based on:                                                               *
- * Version:     $Revision: 1760669 $                                          *
+ * Version:     $Revision: 1840491 $                                          *
  ***************************************************************************/
 
 #include "jk_pool.h"
@@ -369,7 +369,7 @@ void jk_lb_pull(lb_worker_t *p, int locked, jk_logger_t *l)
 }
 
 /* Syncing config values to shm */
-void jk_lb_push(lb_worker_t *p, int locked, jk_logger_t *l)
+void jk_lb_push(lb_worker_t *p, int locked, int push_all_members, jk_logger_t *l)
 {
     unsigned int i = 0;
 
@@ -394,7 +394,7 @@ void jk_lb_push(lb_worker_t *p, int locked, jk_logger_t *l)
 
     for (i = 0; i < p->num_of_workers; i++) {
         lb_sub_worker_t *w = &p->lb_workers[i];
-        if (w->sequence != w->s->h.sequence) {
+        if (push_all_members == JK_TRUE || w->sequence != w->s->h.sequence) {
             jk_worker_t *jw = w->worker;
             ajp_worker_t *aw = (ajp_worker_t *)jw->worker_private;
 
@@ -431,8 +431,7 @@ void jk_lb_push(lb_worker_t *p, int locked, jk_logger_t *l)
 static char *get_path_param(jk_ws_service_t *s, const char *name)
 {
     char *id_start = NULL;
-    for (id_start = strstr(s->req_uri, name);
-         id_start; id_start = strstr(id_start + 1, name)) {
+    for (id_start = strstr(s->req_uri, name); id_start; id_start = strstr(id_start + 1, name)) {
         if (id_start[strlen(name)] == '=') {
             /*
              * Session path-cookie was found, get it's value
@@ -455,6 +454,12 @@ static char *get_path_param(jk_ws_service_t *s, const char *name)
                 if ((id_end = strchr(id_start, ';')) != NULL) {
                     *id_end = '\0';
                 }
+                /*
+                 * Remove any trailing URI segments.
+                 */
+                if ((id_end = strchr(id_start, '/')) != NULL) {
+                    *id_end = '\0';
+                }
                 return id_start;
             }
         }
@@ -1225,8 +1230,11 @@ static int JK_METHOD service(jk_endpoint_t *e,
     if (p->worker->sequence < p->worker->s->h.sequence)
         jk_lb_pull(p->worker, JK_FALSE, l);
     for (i = 0; i < num_of_workers; i++) {
-        lb_sub_worker_t *rec = &(p->worker->lb_workers[i]);
-        ajp_worker_t *aw = (ajp_worker_t *)rec->worker->worker_private;
+        lb_sub_worker_t *rec;
+        ajp_worker_t *aw;
+        jk_log(l, JK_LOG_DEBUG, "LB - num_of_workers: %d, retry: %d, lb_retries: %d", num_of_workers, i, p->worker->lb_retries);
+        rec = &(p->worker->lb_workers[i]);
+        aw = (ajp_worker_t *)rec->worker->worker_private;
         if (rec->s->state == JK_LB_STATE_BUSY) {
             if ((aw->busy_limit <= 0 || aw->s->busy < aw->busy_limit) &&
                 ajp_has_endpoint(rec->worker, l)) {
@@ -1272,7 +1280,10 @@ static int JK_METHOD service(jk_endpoint_t *e,
                p->worker->sticky_session, sessionid ? sessionid : "empty");
 
     while (recoverable == JK_TRUE) {
-        if (attempt >= num_of_workers) {
+        if (JK_IS_DEBUG_LEVEL(l))
+            jk_log(l, JK_LOG_DEBUG, "attempt %d, max attempts %d, worker count %d",
+                    attempt, p->worker->lb_retries, num_of_workers);
+        if (attempt >= num_of_workers || attempt >= p->worker->lb_retries) {
             retry++;
             if (retry >= p->worker->retries) {
                 /* Done with retrying */
@@ -1549,7 +1560,7 @@ static int JK_METHOD service(jk_endpoint_t *e,
                     }
                     else {
                         /*
-                         * Reply timeout, bot not yet too many of them.
+                         * Reply timeout, but not yet too many of them.
                          * Keep previous global state.
                          * Do not try to reuse the same node for the same request.
                          * Failing over to another node could help.
@@ -1760,7 +1771,7 @@ static int JK_METHOD validate(jk_worker_t *pThis,
                         jk_log(l, JK_LOG_DEBUG,
                                "Balanced worker %s already configured (sequence=%d)",
                                p->lb_workers[i].name, p->lb_workers[i].s->h.sequence);
-                    }           
+                    }
                     if (!wc_create_worker(p->lb_workers[i].name, 0,
                                           props,
                                           &(p->lb_workers[i].worker),
@@ -1903,6 +1914,8 @@ static int JK_METHOD init(jk_worker_t *pThis,
     p->worker.we = we;
     p->retries = jk_get_worker_retries(props, p->name,
                                        JK_RETRIES);
+    p->lb_retries = jk_get_worker_lb_retries(props, p->name,
+                                       JK_LB_RETRIES);
     p->retry_interval =
             jk_get_worker_retry_interval(props, p->name,
                                         JK_SLEEP_DEF);
@@ -1959,7 +1972,7 @@ static int JK_METHOD init(jk_worker_t *pThis,
     if (p->s->h.sequence == 0) {
         /* Set configuration data to shared memory
          */
-        jk_lb_push(p, JK_TRUE, log);
+        jk_lb_push(p, JK_TRUE, JK_FALSE, log);
     }
     else {
         /* Shared memory for this worker is already configured.
