@@ -19,7 +19,7 @@
  * Description: load balance worker header file                            *
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  * Author:      Rainer Jung <rjung@apache.org>                             *
- * Version:     $Revision: 1665454 $                                           *
+ * Version:     $Revision: 1838830 $                                           *
  ***************************************************************************/
 
 #ifndef JK_LB_WORKER_H
@@ -187,6 +187,7 @@ struct lb_worker
     int          error_escalation_time;
     int          max_reply_timeouts;
     int          retries;
+    int          lb_retries;
     int          retry_interval;
     int          lbmethod;
     int          lblock;
@@ -219,7 +220,7 @@ const char *jk_lb_get_activation(lb_sub_worker_t *p, jk_logger_t *l);
 int jk_lb_get_activation_code(const char *v);
 void reset_lb_values(lb_worker_t *p, jk_logger_t *l);
 void jk_lb_pull(lb_worker_t * p, int locked, jk_logger_t *l);
-void jk_lb_push(lb_worker_t * p, int locked, jk_logger_t *l);
+void jk_lb_push(lb_worker_t * p, int locked, int push_all_members, jk_logger_t *l);
 void update_mult(lb_worker_t * p, jk_logger_t *l);
 
 #ifdef __cplusplus
