@@ -18,7 +18,7 @@
 /***************************************************************************
  * Description: Multi thread portability code for JK                       *
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
- * Version:     $Revision: 915199 $                                           *
+ * Version:     $Revision: 1837376 $                                           *
  ***************************************************************************/
 
 #ifndef _JK_MT_H
@@ -29,8 +29,6 @@
 
 #if defined(WIN32)
 #define jk_gettid()    ((jk_uint32_t)GetCurrentThreadId())
-#elif defined(NETWARE) && !defined(__NOVELL_LIBC__)
-#define getpid()       ((int)GetThreadGroupID())
 #endif
 
 #ifdef JK_PREFORK 
@@ -47,10 +45,10 @@
 #include <windows.h>
 
 typedef CRITICAL_SECTION JK_CRIT_SEC;
-#define JK_INIT_CS(x, rc) InitializeCriticalSection(x); rc = JK_TRUE
-#define JK_DELETE_CS(x, rc) DeleteCriticalSection(x);   rc = JK_TRUE
-#define JK_ENTER_CS(x, rc) EnterCriticalSection(x);     rc = JK_TRUE
-#define JK_LEAVE_CS(x, rc) LeaveCriticalSection(x);     rc = JK_TRUE
+#define JK_INIT_CS(x, rc)   InitializeCriticalSection(x); rc = JK_TRUE
+#define JK_DELETE_CS(x)     DeleteCriticalSection(x)
+#define JK_ENTER_CS(x)      EnterCriticalSection(x)
+#define JK_LEAVE_CS(x)      LeaveCriticalSection(x)
 
 #else /* !WIN32 */
 #define _MT_CODE_PTHREAD
@@ -59,19 +57,14 @@ typedef CRITICAL_SECTION JK_CRIT_SEC;
 #include <fcntl.h>
 
 typedef pthread_mutex_t JK_CRIT_SEC;
-#define JK_INIT_CS(x, rc)\
-            if(pthread_mutex_init(x, NULL)) rc = JK_FALSE; else rc = JK_TRUE
+#define JK_INIT_CS(x, rc)       \
+            if (pthread_mutex_init(x, NULL)) rc = JK_FALSE; else rc = JK_TRUE
 
-#define JK_DELETE_CS(x, rc)\
-            if(pthread_mutex_destroy(x))    rc = JK_FALSE; else rc = JK_TRUE
+#define JK_DELETE_CS(x) pthread_mutex_destroy(x)
+#define JK_ENTER_CS(x)  pthread_mutex_lock(x)
+#define JK_LEAVE_CS(x)  pthread_mutex_unlock(x)
 
-#define JK_ENTER_CS(x, rc)\
-            if(pthread_mutex_lock(x))       rc = JK_FALSE; else rc = JK_TRUE
-
-#define JK_LEAVE_CS(x, rc)\
-            if(pthread_mutex_unlock(x))     rc = JK_FALSE; else rc = JK_TRUE
-
-#ifdef AS400
+#if defined(AS400)
 #define jk_pthread_t   jk_uint32_t
 #endif /* AS400 */
 jk_pthread_t jk_gettid(void);
@@ -81,23 +74,25 @@ jk_pthread_t jk_gettid(void);
 
 typedef void *JK_CRIT_SEC;
 #define JK_INIT_CS(x, rc)   rc = JK_TRUE
-#define JK_DELETE_CS(x, rc) rc = JK_TRUE
-#define JK_ENTER_CS(x, rc)  rc = JK_TRUE
-#define JK_LEAVE_CS(x, rc)  rc = JK_TRUE
+#define JK_DELETE_CS(x)     (void)0
+#define JK_ENTER_CS(x)      (void)0
+#define JK_LEAVE_CS(x)      (void)0
 #define jk_gettid()         0
 #endif /* MT_CODE */
 
-#if !defined(WIN32) && !defined(NETWARE)
+#if !defined(WIN32)
 #include <unistd.h>
 #include <fcntl.h>
 
 
-#define USE_FLOCK_LK 0
 #if HAVE_FLOCK
 #ifdef JK_USE_FLOCK
 #define USE_FLOCK_LK 1
 #endif
 #endif
+#ifndef USE_FLOCK_LK
+#define USE_FLOCK_LK 0
+#endif
 
 #if USE_FLOCK_LK
 #include <sys/file.h>
@@ -142,7 +137,7 @@ typedef void *JK_CRIT_SEC;
 
 #endif /* USE_FLOCK_LK */
 
-#else  /* WIN32 || NETWARE */
+#else  /* WIN32 */
 #define JK_ENTER_LOCK(x, rc) rc = JK_TRUE
 #define JK_LEAVE_LOCK(x, rc) rc = JK_TRUE
 #endif
