@@ -18,7 +18,7 @@
 /***************************************************************************
  * Description: Memory Pool object header file                             *
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
- * Version:     $Revision: 466585 $                                           *
+ * Version:     $Revision: 1837375 $                                           *
  ***************************************************************************/
 #ifndef _JK_POOL_H
 #define _JK_POOL_H
@@ -59,8 +59,6 @@ extern "C"
     typedef long long jk_pool_atom_t;
 #elif defined(OS2)
     typedef long long jk_pool_atom_t;
-#elif defined(NETWARE)
-    typedef long long jk_pool_atom_t;
 #elif defined(HPUX11)
     typedef long long jk_pool_atom_t;
 #elif defined(IRIX)
@@ -115,10 +113,16 @@ void jk_reset_pool(jk_pool_t *p);
 
 void *jk_pool_alloc(jk_pool_t *p, size_t sz);
 
+void *jk_pool_calloc(jk_pool_t *p, size_t sz);
+
 void *jk_pool_realloc(jk_pool_t *p,
                       size_t sz, const void *old, size_t old_sz);
 
-void *jk_pool_strdup(jk_pool_t *p, const char *s);
+char *jk_pool_strdup(jk_pool_t *p, const char *s);
+
+char *jk_pool_strcat(jk_pool_t *p, const char *s, const char *a);
+
+char *jk_pool_strcatv(jk_pool_t *p, ...);
 
 #ifdef __cplusplus
 }
