@@ -22,7 +22,7 @@
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  * Author:      Dan Milstein <danmil@shore.net>                            *
  * Author:      Henri Gomez <hgomez@apache.org>                            *
- * Version:     $Revision: 1188097 $                                          *
+ * Version:     $Revision: 1838830 $                                          *
  ***************************************************************************/
 
 #ifndef JK_SERVICE_H
@@ -36,6 +36,7 @@
 #include "jk_msg_buff.h"
 
 #define JK_RETRIES 2
+#define JK_LB_RETRIES 2
 
 #ifdef __cplusplus
 extern "C"
@@ -101,6 +102,10 @@ struct svc_extension
     char *session_cookie;
     /* session_path overwrite */
     char *session_path;
+    /* Whether mod_jk should set the session cookie itself */
+    int set_session_cookie;
+    /* An optional PATH to add the the set session cookie */
+    char *session_cookie_path;
 };
 typedef struct svc_extension svc_extension_t;
 
@@ -164,6 +169,7 @@ struct jk_ws_service
     const char *auth_type;
     const char *query_string;
     const char *server_name;
+    const char *local_addr;
     unsigned server_port;
     char *server_software;
     jk_uint64_t content_length; /* 64 bit integer that represents the content */
@@ -176,6 +182,7 @@ struct jk_ws_service
      * SSL information
      *
      * is_ssl       - True if request is in ssl connection
+     * ssl_protocol-  Name of the SSL protocol (SSLv3, TLSv1, TLSv1.1, TLSv1.2)
      * ssl_cert     - If available, base64 ASN.1 encoded client certificates.
      * ssl_cert_len - Length of ssl_cert, 0 if certificates are not available.
      * ssl_cipher   - The ssl cipher suite in use.
@@ -185,6 +192,7 @@ struct jk_ws_service
      * case, we are passing NULL.
      */
     int is_ssl;
+    char *ssl_protocol;
     char *ssl_cert;
     unsigned ssl_cert_len;
     char *ssl_cipher;
@@ -204,7 +212,6 @@ struct jk_ws_service
     char **headers_values;  /* Values of the request headers */
     unsigned num_headers;   /* Number of request headers     */
 
-
     /*
      * Request attributes.
      *
@@ -219,6 +226,22 @@ struct jk_ws_service
     char **attributes_values;       /* Values of the request attributes */
     unsigned num_attributes;        /* Number of request attributes     */
 
+    /*
+     * Response headers, names and values.
+     * These are additional headers that we want to add to
+     * the headers send to us from tomcat.
+     * Example: a stickyness cookie header
+     */
+    char **resp_headers_names;   /* Names of the response headers  */
+    char **resp_headers_values;  /* Values of the response headers */
+    unsigned num_resp_headers;   /* Number of response headers     */
+
+    /*
+     * JK_TRUE iff handled by a load balancer, the request
+     * contained a route and it is the route of the current worker.
+     */
+    int sticky;
+
     /*
      * The route is in use when the adapter load balance among
      * several workers. It is the ID of a specific target in the load balance
@@ -524,7 +547,12 @@ struct jk_worker
     /*
      * Maintain this worker.
      */
-    int (JK_METHOD * maintain) (jk_worker_t *w, time_t now, jk_logger_t *l);
+    int (JK_METHOD * maintain) (jk_worker_t *w, time_t now, int global, jk_logger_t *l);
+
+    /*
+     * Shut this worker down.
+     */
+    int (JK_METHOD * shutdown) (jk_worker_t *w, jk_logger_t *l);
 
 };
 
