@@ -19,7 +19,7 @@
  * Description: Shared Memory support                                      *
  * Author:      Mladen Turk <mturk@jboss.com>                              *
  * Author:      Rainer Jung <rjung@apache.org>                             *
- * Version:     $Revision: 1665454 $                                        *
+ * Version:     $Revision: 1838573 $                                        *
  ***************************************************************************/
 
 #include "jk_global.h"
@@ -188,7 +188,7 @@ int jk_shm_calculate_size(jk_map_t *init_data, jk_logger_t *l)
 }
 
 
-#if defined (WIN32) || defined(NETWARE)
+#if defined (WIN32)
 
 /* Use plain memory */
 int jk_shm_open(const char *fname, int sz, jk_logger_t *l)
@@ -223,7 +223,7 @@ int jk_shm_open(const char *fname, int sz, jk_logger_t *l)
     if (fname) {
         int i;
         SIZE_T shmsz = 0;
-        strcpy(shname, "Global\\");
+        strcpy(shname, "Local\\");
         strncat(shname, fname, MAX_PATH - 8);
         for(i = 7; i < (int)strlen(shname); i++) {
             if (!jk_isalnum(shname[i]))
@@ -878,7 +878,7 @@ int jk_shm_check_maintain(time_t trigger)
         JK_ATOMIC_DECREMENT(&(jk_shmem.hdr->h.data.maintain_checking));
         return rv;
     }
-    if (jk_shmem.hdr->h.data.maintain_time < trigger) {
+    if (jk_shmem.hdr->h.data.maintain_time <= trigger) {
         jk_shmem.hdr->h.data.maintain_time = time(NULL);
         rv = JK_TRUE;
     }
