@@ -1,9 +1,10 @@
 /*
- *  Copyright 1999-2004 The Apache Software Foundation
- *
- *  Licensed under the Apache License, Version 2.0 (the "License");
- *  you may not use this file except in compliance with the License.
- *  You may obtain a copy of the License at
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
  *
  *      http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -17,7 +18,7 @@
 /***************************************************************************
  * Description: Socket buffer header file                                  *
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
- * Version:     $Revision: 422996 $                                           *
+ * Version:     $Revision: 466585 $                                           *
  ***************************************************************************/
 
 #include "jk_global.h"
@@ -33,7 +34,7 @@ struct jk_sockbuf
 };
 typedef struct jk_sockbuf jk_sockbuf_t;
 
-int jk_sb_open(jk_sockbuf_t *sb, int sd);
+int jk_sb_open(jk_sockbuf_t *sb, jk_sock_t sd);
 
 int jk_sb_write(jk_sockbuf_t *sb, const void *buf, unsigned sz);
 
