@@ -20,7 +20,7 @@
  *                                                                         *
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  * Author:      Mladen Turk <mturk@apache.org>                             *
- * Version:     $Revision: 1649849 $                                          *
+ * Version:     $Revision: 1840607 $                                          *
  ***************************************************************************/
 
 #include "jk_pool.h"
@@ -176,10 +176,9 @@ static void uri_worker_map_dump(jk_uri_worker_map_t *uw_map,
         int i, off;
         if (JK_IS_DEBUG_LEVEL(l)) {
             jk_log(l, JK_LOG_DEBUG, "uri map dump %s: id=%d, index=%d file='%s' reject_unsafe=%d "
-                  "collapse_slashes=%d reload=%d modified=%d checked=%d",
+                  "reload=%d modified=%d checked=%d",
                    reason, uw_map->id, uw_map->index, STRNULL_FOR_NULL(uw_map->fname),
-                   uw_map->reject_unsafe, uw_map->collapse_slashes,
-                   uw_map->reload, uw_map->modified, uw_map->checked);
+                   uw_map->reject_unsafe, uw_map->reload, uw_map->modified, uw_map->checked);
         }
         for (i = 0; i <= 1; i++) {
             jk_log(l, JK_LOG_DEBUG, "generation %d: size=%d nosize=%d capacity=%d",
@@ -245,7 +244,6 @@ int uri_worker_map_alloc(jk_uri_worker_map_t **uw_map_p,
         uw_map->index = 0;
         uw_map->fname = NULL;
         uw_map->reject_unsafe = 0;
-        uw_map->collapse_slashes = JK_COLLAPSE_DEFAULT;
         uw_map->reload = JK_URIMAP_DEF_RELOAD;
         uw_map->modified = 0;
         uw_map->checked = 0;
@@ -429,6 +427,7 @@ static void extension_fix_fail_on_status(jk_pool_t *p,
     unsigned int i;
     int j;
     int cnt = 1;
+    size_t status_len;
     char *status;
 #ifdef _MT_CODE_PTHREAD
     char *lasts;
@@ -436,7 +435,8 @@ static void extension_fix_fail_on_status(jk_pool_t *p,
 
     JK_TRACE_ENTER(l);
 
-    for (i = 0; i < (unsigned int)strlen(extensions->fail_on_status_str); i++) {
+    status_len = strlen(extensions->fail_on_status_str);
+    for (i = 0; i < status_len; i++) {
         if (extensions->fail_on_status_str[i] == ',' ||
             extensions->fail_on_status_str[i] == ' ')
             cnt++;
@@ -1072,7 +1072,8 @@ const char *map_uri_to_worker_ext(jk_uri_worker_map_t *uw_map,
     unsigned int i;
     unsigned int vhost_len;
     int reject_unsafe;
-    int collapse_slashes;
+    size_t uri_len;
+    size_t remain;
     int rv = -1;
     char  url[JK_MAX_URI_LEN+1];
 
@@ -1111,7 +1112,6 @@ const char *map_uri_to_worker_ext(jk_uri_worker_map_t *uw_map,
         }
     }
     reject_unsafe = uw_map->reject_unsafe;
-    collapse_slashes = uw_map->collapse_slashes;
     vhost_len = 0;
     /*
      * In case we got a vhost, we prepend a slash
@@ -1136,45 +1136,34 @@ const char *map_uri_to_worker_ext(jk_uri_worker_map_t *uw_map,
         }
         else {
             strncpy(&url[off], vhost, vhost_len + 1);
+            if (JK_IS_DEBUG_LEVEL(l)) {
+                jk_log(l, JK_LOG_DEBUG, "Prefixing mapping uri with vhost '%s'", vhost);
+            }
         }
         vhost_len += off;
     }
-    /* Make the copy of the provided uri and strip
-     * everything after the first ';' char.
+    /* Make the copy of the provided uri, check length
+     * and look for potentially unsafe constructs
      */
-    for (i = 0; i < strlen(uri); i++) {
-        if (i == JK_MAX_URI_LEN) {
+    uri_len = strlen(uri);
+    remain = JK_MAX_URI_LEN - vhost_len;
+    for (i = 0; i < uri_len; i++) {
+        if (i == remain) {
             jk_log(l, JK_LOG_WARNING,
                    "URI %s is invalid. URI must be smaller than %d chars",
-                   uri, JK_MAX_URI_LEN);
+                   uri, remain);
             JK_TRACE_EXIT(l);
             return NULL;
         }
-        if (uri[i] == ';')
-            break;
-        else {
-            url[i + vhost_len] = uri[i];
-            if (reject_unsafe && (uri[i] == '%' || uri[i] == '\\')) {
-                jk_log(l, JK_LOG_INFO, "Potentially unsafe request url '%s' rejected", uri);
-                JK_TRACE_EXIT(l);
-                return NULL;
-            }
+        url[i + vhost_len] = uri[i];
+        if (reject_unsafe && (uri[i] == '%' || uri[i] == '\\')) {
+            jk_log(l, JK_LOG_INFO, "Potentially unsafe request url '%s' rejected", uri);
+            JK_TRACE_EXIT(l);
+            return NULL;
         }
     }
     url[i + vhost_len] = '\0';
 
-    if (JK_IS_DEBUG_LEVEL(l)) {
-        char *url_rewrite = strstr(uri, JK_PATH_SESSION_IDENTIFIER);
-        if (url_rewrite)
-            jk_log(l, JK_LOG_DEBUG, "Found session identifier '%s' in url '%s'",
-                   url_rewrite, uri);
-    }
-    if (collapse_slashes == JK_COLLAPSE_ALL) {
-        /* Remove multiple slashes
-         * No need to copy url, because it is local and
-         * the unchanged url is no longer needed */
-        jk_no2slash(url);
-    }
     if (JK_IS_DEBUG_LEVEL(l))
         jk_log(l, JK_LOG_DEBUG, "Attempting to map URI '%s' from %d maps",
                url, IND_THIS(uw_map->size));
@@ -1187,13 +1176,6 @@ const char *map_uri_to_worker_ext(jk_uri_worker_map_t *uw_map,
     /* In case we found a match, check for the unmounts. */
     if (rv >= 0 && IND_THIS(uw_map->nosize)) {
         int rc;
-        if (collapse_slashes == JK_COLLAPSE_UNMOUNT) {
-            /* Remove multiple slashes when looking for
-             * unmount to prevent trivial unmount bypass attack.
-             * No need to copy url, because it is local and
-             * the unchanged url is no longer needed */
-            jk_no2slash(url);
-        }
         /* Again first including vhost. */
         rc = is_nomatch(uw_map, url, rv, l);
         /* If no unmount was found, try without vhost. */
@@ -1231,14 +1213,6 @@ rule_extension_t *get_uri_to_worker_ext(jk_uri_worker_map_t *uw_map,
     }
 }
 
-const char *map_uri_to_worker(jk_uri_worker_map_t *uw_map,
-                              const char *uri, const char *vhost,
-                              jk_logger_t *l)
-{
-    rule_extension_t *ext;
-    return map_uri_to_worker_ext(uw_map, uri, vhost, &ext, NULL, l);
-}
-
 int uri_worker_map_load(jk_uri_worker_map_t *uw_map,
                         jk_logger_t *l)
 {
