@@ -20,7 +20,7 @@
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  * Author:      Henri Gomez <hgomez@apache.org>                            *
  * Author:      Rainer Jung <rjung@apache.org>                             *
- * Version:     $Revision: 1658173 $                                          *
+ * Version:     $Revision: 1840629 $                                          *
  ***************************************************************************/
 #ifndef _JK_UTIL_H
 #define _JK_UTIL_H
@@ -60,7 +60,7 @@ int jk_log(jk_logger_t *l,
 
 int jk_check_attribute_length(const char *name, const char *value,
                               jk_logger_t *l);
-    
+
 const char *jk_get_worker_host(jk_map_t *m, const char *wname, const char *def);
 
 const char *jk_get_worker_source(jk_map_t *m, const char *wname, const char *def);
@@ -131,6 +131,8 @@ const char *jk_get_lb_session_cookie_path(jk_map_t *m, const char *wname, const
 
 int jk_get_worker_retries(jk_map_t *m, const char *wname, int def);
 
+int jk_get_worker_lb_retries(jk_map_t *m, const char *wname, int def);
+
 int jk_get_is_worker_disabled(jk_map_t *m, const char *wname);
 
 int jk_get_is_worker_stopped(jk_map_t *m, const char *wname);
@@ -188,7 +190,7 @@ int jk_is_unique_property(const char *prp_name);
 int jk_is_deprecated_property(const char *prp_name);
 
 int jk_check_buffer_size();
-    
+
 int jk_is_valid_property(const char *prp_name);
 
 int jk_get_worker_stdout(jk_map_t *m, const char *wname, const char **stdout_name);
@@ -246,7 +248,12 @@ int is_http_status_fail(unsigned int http_status_fail_num,
 
 int jk_wildchar_match(const char *str, const char *exp, int icase);
 
-void jk_no2slash(char *name);
+int jk_servlet_normalize(char *path, jk_logger_t *logger);
+
+int jk_strip_session_id(char* path, char* session_name, jk_logger_t *logger);
+
+#define JK_NORMALIZE_BAD_PATH   -1
+#define JK_NORMALIZE_TRAVERSAL  -2
 
 #define TC32_BRIDGE_TYPE    32
 #define TC33_BRIDGE_TYPE    33
